summaryrefslogtreecommitdiff
path: root/nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-04-01 22:00:37 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-04-01 22:00:37 +0000
commit87590afa9ca772243c261e6c1b8478565bd2771a (patch)
treed7a3161c5dea29510630f239e027dc32bac968fc /nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c
parentf7122813d51018e5d3460a30596d2320a08ef740 (diff)
downloadpx4-nuttx-87590afa9ca772243c261e6c1b8478565bd2771a.tar.gz
px4-nuttx-87590afa9ca772243c261e6c1b8478565bd2771a.tar.bz2
px4-nuttx-87590afa9ca772243c261e6c1b8478565bd2771a.zip
More naming changes associated with earlier renaming of LP17xx up_spiinitialize; LPC178x SSP support; Open1788 SSP and touchscreen support
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5811 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c')
-rw-r--r--nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c b/nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c
index 9766569a9..53e4c2a9d 100644
--- a/nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c
+++ b/nuttx/configs/lpcxpresso-lpc1768/src/up_boot.c
@@ -75,13 +75,13 @@
void lpc17_boardinitialize(void)
{
/* Configure SSP chip selects if 1) at least one SSP is enabled, and 2) the weak
* function lpc17_sspinitialize() has been brought into the link.
*/
#if defined(CONFIG_LPC17_SSP0) || defined(CONFIG_LPC17_SSP1)
- if (lpc17_sspinitialize)
+ if (lpcxpresso_sspinitialize)
{
- lpc17_sspinitialize();
+ lpcxpresso_sspinitialize();
}
#endif
@@ -75,13 +75,13 @@
{
/* Configure SSP chip selects if 1) at least one SSP is enabled, and 2) the weak
- * function lpc17_sspinitialize() has been brought into the link.
+ * function lpcxpresso_sspinitialize() has been brought into the link.
*/
#if defined(CONFIG_LPC17_SSP0) || defined(CONFIG_LPC17_SSP1)